#!/bin/bash
### BEGIN INIT INFO
# Provides:          vps-control
# Required-Start:    
# Required-Stop:     
# Should-Start:      postgresql openvpn
# Should-Stop:       postgresql openvpn
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Script de inicio del vps-control
# Description:       This file should be used to construct scripts to be
#                    placed in /etc/init.d.
### END INIT INFO

PATH=/sbin:/usr/sbin:/bin:/usr/bin
SOFTNAME=vps-control
DESC="$SOFTNAME daemon"
NAME=vps-control-websocket-proxy-daemon.php
DAEMON=/usr/lib/vps-control/bin/$NAME
DAEMON_ARGS=""
PIDFILE=/var/run/$NAME.pid
SCRIPTNAME=/usr/lib/vps-control/init.d/$(basename $NAME php)sh
RUN=no

# Exit if the package is not installed
[ -x "$DAEMON" ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$SOFTNAME ] && . /etc/default/$SOFTNAME

# Load the VERBOSE setting and other rcS variables
. /lib/init/vars.sh

# Define LSB log_* functions.
# Depend on lsb-base (>= 3.0-6) to ensure that this file is present.
. /lib/lsb/init-functions

#
# Function that starts the daemon/service
#
do_start()
{
        # Return
        #   0 if daemon has been started
        #   1 if daemon was already running
        #   2 if daemon could not be started

	${DAEMON} start
        RETVAL=$?
        #[ "$RETVAL" = "0" ] && return 0
        return ${RETVAL}
        # Add code here, if necessary, that waits for the process to be ready
        # to handle requests from services started subsequently which depend
        # on this one.  As a last resort, sleep for some time.
}


#
# Function that stops the daemon/service
#
do_stop()
{
        # Return
        #   0 if daemon has been stopped
        #   1 if daemon was already stopped
        #   2 if daemon could not be stopped
        #   other if a failure occurred

	${DAEMON} stop
        RETVAL=$?
        #[ "$RETVAL" = "0" ] && return 0
        return ${RETVAL}
        # Wait for children to finish too if this is a daemon that forks
        # and if the daemon is only ever run from this initscript.
        # If the above conditions are not satisfied then add some other code
        # that waits for the process to drop all resources that could be
        # needed by services started subsequently.  A last resort is to
        # sleep for some time.
}

#
# Function that sends a SIGHUP to the daemon/service
#
do_restart() {
        #
        # If the daemon can reload its configuration without
        # restarting (for example, when it is sent a SIGHUP),
        # then implement that here.
        #
	do_stop
	/bin/sleep 4
	do_start
        RETVAL=$?
        #[ "$RETVAL" = "0" ] && return 0
        return ${RETVAL}
}

do_reload() {
        #
        # If the daemon can reload its configuration without
        # restarting (for example, when it is sent a SIGHUP),
        # then implement that here.
        #
	do_stop
	/bin/sleep 4
	do_start
        RETVAL=$?
        #[ "$RETVAL" = "0" ] && return 0
        return ${RETVAL}
}


if [ "x$RUN" != "xyes" ]
then
  /bin/echo "$SOFTNAME disabled; edit /etc/default/$SOFTNAME"
  exit 0
fi

RET_VAL=0

case "$1" in
  start)
        #log_daemon_msg "Starting $DESC" "$NAME"
        log_daemon_msg "${SOFTNAME}"
        do_start
        RET_VAL=$?
        case "${RET_VAL}" in
                0) log_end_msg 0 ;;
                1) log_end_msg 0 ;;
                2) log_end_msg 1 ;;
                *) log_end_msg 1 ;;
        esac
        ;;
        
  stop)
        #log_daemon_msg "Stopping $DESC" "$NAME"
        log_daemon_msg "${SOFTNAME}"
        do_stop
        RET_VAL=$?
        case "${RET_VAL}" in
                0) log_end_msg 0 ;;
                1) log_end_msg 0 ;;
                2) log_end_msg 1 ;;
                *) log_end_msg 1 ;;
        esac
        ;;

  reload)
        #log_daemon_msg "Suspending $DESC" "$NAME"
        log_daemon_msg "${SOFTNAME}"
        do_reload
        RET_VAL=$?
        case "${RET_VAL}" in
                0) log_end_msg 0 ;;
                1) log_end_msg 0 ;;
                2) log_end_msg 1 ;;
                *) log_end_msg 1 ;;
        esac
        ;;

  restart|force-reload)
        #
        # If the "reload" option is implemented then remove the
        # 'force-reload' alias
        #
        # log_daemon_msg "Restarting $DESC" "$NAME"
        #log_daemon_msg "Suspending $DESC" "$NAME"
        log_daemon_msg "${SOFTNAME}"
        do_restart
        RET_VAL=$?
        case "${RET_VAL}" in
                0) log_end_msg 0 ;;
                1) log_end_msg 0 ;;
                2) log_end_msg 1 ;;
                *) log_end_msg 1 ;;
        esac
        ;;
  *)
        #echo "Usage: $SCRIPTNAME {start|stop|restart|reload|force-reload}" >&2
        echo "Usage: $SCRIPTNAME {start|stop|suspend|resume|restart|reload|force-reload}" >&2
        exit 3
        ;;
esac

exit ${RET_VAL}
