#!/bin/bash

SOFTNAME=vps-control
DESC="$SOFTNAME websocket-proxy daemon"
NAME=vps-control-websocket-proxy-daemon.php
DAEMON=/usr/lib/vps-control/bin/$NAME
DAEMON_ARGS=""
PIDFILE=/var/run/$NAME.pid
SCRIPTNAME=/usr/lib/vps-control/systemd/$(basename $0)
RUN=no

# Exit if the package is not installed
[ -x "$DAEMON" ] || exit 0

# Read configuration variable file if it is present
[ -r /etc/default/$SOFTNAME ] && . /etc/default/$SOFTNAME


#
# Function that starts the daemon/service
#
do_start()
{
    # Return
    #   0 if daemon has been started
    #   1 if daemon was already running
    #   2 if daemon could not be started

    ${DAEMON} start
    RETVAL=$?

    return ${RETVAL}
}


#
# Function that stops the daemon/service
#
do_stop()
{
    # Return
    #   0 if daemon has been started
    #   1 if daemon was already running
    #   2 if daemon could not be started
    
    ${DAEMON} stop
    RETVAL=$?

    return ${RETVAL}
}

#
# Function that sends a SIGHUP to the daemon/service
#
do_reload()
{
	do_stop
	/bin/sleep 4
	do_start
    RETVAL=$?
    return ${RETVAL}
}

if [ "x$RUN" != "xyes" ]
then
  if [ "$1" != "stop" ]
  then
    /bin/sleep 9 &
    /bin/echo $! > ${PIDFILE}
  fi

  /bin/echo "$SOFTNAME disabled; edit /etc/default/$SOFTNAME"
  exit 0
fi

RET_VAL=0
EXTRA_COMMAND=$2

case "$1" in
  start)
        do_start ${EXTRA_COMMAND}
        RET_VAL=$?
        ;;
        
  stop)
        do_stop ${EXTRA_COMMAND}
        RET_VAL=$?
        ;;

  reload)
        do_reload
        RET_VAL=$?
        ;;

  *)
        echo "Usage: $SCRIPTNAME {start|stop|reload}" >&2
        exit 3
        ;;
esac

exit ${RET_VAL}
